<?php

/**
 * Blackbird MenuManager Module
 *
 * NOTICE OF LICENSE
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@bird.eu so we can send you a copy immediately.
 *
 * @category            Blackbird
 * @package        Blackbird_MenuManager
 * @copyright           Copyright (c) 2016 Blackbird (http://black.bird.eu)
 * @author        Blackbird Team
 */

namespace FiloBlu\ExtBlackbirdMenuManager\Plugin\Block\NodeType;

use Blackbird\MenuManager\Api\NodeRepositoryInterface;
use Closure;
use Magento\Customer\Model\Context;
use Magento\Customer\Model\Session;

/**
 * Class AbstractNodeTypeFront
 * @package FiloBlu\ExtBlackbirdMenuManager\Plugin\Block\NodeType
 */
class AbstractNodeTypeFront
{
    /**
     * @var Session
     */
    protected $_customerSession;
    /**
     * @var \Magento\Framework\App\Http\Context
     */
    protected $_context;
    /**
     * @var NodeRepositoryInterface
     */
    protected $nodeRepository;

    /**
     * AbstractNodeTypeFront constructor.
     * @param Session $customerSession
     * @param \Magento\Framework\App\Http\Context $context
     * @param NodeRepositoryInterface $nodeRepository
     */
    public function __construct(
        Session $customerSession, \Magento\Framework\App\Http\Context $context, NodeRepositoryInterface $nodeRepository
    )
    {
        $this->_customerSession = $customerSession;
        $this->_context = $context;
        $this->nodeRepository = $nodeRepository;
    }

    /**
     * @param \Blackbird\MenuManager\Block\NodeType\AbstractNodeTypeFront $subject
     * @param Closure $proceed
     * @param $urlNodeItem
     * @param $node
     * @param $childrenArray
     * @return bool|mixed
     */
    public function aroundIsActive(\Blackbird\MenuManager\Block\NodeType\AbstractNodeTypeFront $subject, Closure $proceed, $urlNodeItem, $node, $childrenArray)
    {

        $originalResult = $proceed($urlNodeItem, $node, $childrenArray);

        if ($originalResult) {
            if (!$urlNodeItem || $urlNodeItem == '/') {
                return false;
            }
        }

        return $originalResult;

    }

    /**
     * @param \Blackbird\MenuManager\Block\NodeType\AbstractNodeTypeFront $subject
     * @param Closure $proceed
     * @param $type
     * @param $menuIdentifier
     * @return \Blackbird\MenuManager\Block\NodeType\AbstractNodeTypeFront
     */
    public function aroundPrepareTemplate(\Blackbird\MenuManager\Block\NodeType\AbstractNodeTypeFront $subject, Closure $proceed, $type, $menuIdentifier)
    {
        $proceed($type, $menuIdentifier);

        $subject->setTemplate('Blackbird_MenuManager::menu/view/' . $menuIdentifier . '/nodetype/' . $type . '.phtml');

        //Custom template if existing
        //$menuidentifier is the identifier of the menu used for every pages defined in the default.xml
        $subject->setTemplate('Blackbird_MenuManager::menu/view/' . $menuIdentifier . '/nodetype/' . $type . '.phtml');

        if (!$subject->getTemplateFile()) {
            //default case
            $subject->setTemplate('FiloBlu_ExtBlackbirdMenuManager::menu/view/default/nodetype/' . $type . '.phtml');

            if (!$subject->getTemplateFile()) {
                $subject->setTemplate('Blackbird_MenuManager::menu/view/default/nodetype/' . $type . '.phtml');
            }
        }

        return $subject;
    }

    /**
     * @param \Blackbird\MenuManager\Block\NodeType\AbstractNodeTypeFront $subject
     * @param Closure $proceed
     * @param $nodeId
     * @param $level
     * @param $classes
     * @param $childrenHtml
     * @param $childrenArray
     * @param $storeId
     * @return mixed
     */
    public function aroundGetHtml(\Blackbird\MenuManager\Block\NodeType\AbstractNodeTypeFront $subject, Closure $proceed, $nodeId, $level, $classes, $childrenHtml, $childrenArray, $storeId)
    {

        $node = $this->nodeRepository->getById($nodeId);

        $subject->setCustomerGroup($node->getData('customer_group'));

        return $proceed($nodeId, $level, $classes, $childrenHtml, $childrenArray, $storeId);
    }

    /**
     * @param \Blackbird\MenuManager\Block\NodeType\AbstractNodeTypeFront $subject
     * @param $result
     * @return string
     */
    public function afterToHtml(\Blackbird\MenuManager\Block\NodeType\AbstractNodeTypeFront $subject, $result)
    {

        if ($arrayCustomerGroup = $subject->getCustomerGroup()) {

            $arrayCustomerGroup = explode(',', $arrayCustomerGroup);
            $_currentCustomerGroupId = '-1';

            if ($this->_context->getValue(Context::CONTEXT_AUTH)) {
                $_currentCustomerGroupId = '-2,';
                $_currentCustomerGroupId .= $this->_customerSession->getCustomer()->getGroupId();
            }

            $_currentCustomerGroupIdArray = explode(',', $_currentCustomerGroupId);

            $found = false;

            foreach ($_currentCustomerGroupIdArray as $groupIdVal) {
                if (in_array($groupIdVal, $arrayCustomerGroup, false)) {
                    $found = true;
                }
            }

            if ($found) {
                return $result;
            }

            return '';
        }

        return $result;
    }

}
